(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     45265,       1058]
NotebookOptionsPosition[     43392,        991]
NotebookOutlinePosition[     43728,       1006]
CellTagsIndexPosition[     43685,       1003]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"Nonlinear", " ", "Fit", " ", "to", " ", "data"}], 
   "Title"]}]], "Input"],

Cell["\<\
This Notebook does a nonlinear fit using as an example  a voltage divider \
with a resistor as \"R\" and a black box with a capacitor and resistor in \
parallel as \"R2\".  The magnitude of the gain is fit to the data.  \
\>", "Text",
 CellChangeTimes->{{3.427142173392831*^9, 3.4271422081223097`*^9}, {
  3.427142720765334*^9, 3.4271427464261303`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "=", "x"}], ";", 
  RowBox[{"Remove", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "\"\<spell1\>\""}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Complex Algebra",
  FormatType->StandardForm,
  FontFamily->"Arial",
  FontSize->14],
 StyleBox["\n",
  FormatType->StandardForm,
  FontFamily->"Times New Roman",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
    "The", " ", "complex", " ", "quantity", " ", "z", " ", "must", " ", "be", 
     " ", "written", " ", "in", " ", "terms", " ", "of", " ", "real", " ", 
     "numbers"}],
    FontSize->12], TraditionalForm]]],
 StyleBox["\:f35f",
  FormatType->StandardForm,
  FontSize->14]
}], "Subsection"],

Cell["\<\
This is not necessary, but makes mathematica treat the numbers in your \
expressions as real when taking the real and imaginary components.  I find it \
useful, but if you use this tool, make sure you understand it.  It changes \
nothing about the nonlinear fit.\
\>", "Text"],

Cell[TextData[StyleBox["conjugateRule={Complex[re_,im_]:>Complex[re,-im]};\n\
conjugate[z_]:=z/.conjugateRule;\nreal[z_]:=(1/2)*(z+conjugate[z])//Simplify;\
\nimag[z_]:=(-I/2)*(z-conjugate[z])//Simplify;\n\
abs[z_]:=Sqrt[(z*(z/.conjugateRule))]//Simplify;",
 FormatType->StandardForm,
 FontFamily->"Courier New"]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of Data Fit", "Section"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"ztotal", ",", "z2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"z2", "=", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"I", " ", "\[Omega]", " ", "L"}], ")"}]}], "+", 
      RowBox[{"(", 
       RowBox[{"I", " ", "\[Omega]", " ", "C"}], ")"}]}], ")"}]}]}], ";", 
  RowBox[{"ztotal", "=", 
   RowBox[{"R", "+", "z2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.427143392024723*^9, 3.427143408523128*^9}, {
  3.427143937603718*^9, 3.427143945675198*^9}, {3.427145071496572*^9, 
  3.427145073637906*^9}, {3.4271458171575413`*^9, 3.4271458196355257`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G", "=", 
  RowBox[{"z2", "/", 
   RowBox[{"(", "ztotal", ")"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["\[ImaginaryI]", 
       RowBox[{"L", " ", "\[Omega]"}]]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "C", " ", "\[Omega]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"R", "+", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[ImaginaryI]", 
         RowBox[{"L", " ", "\[Omega]"}]]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "C", " ", "\[Omega]"}]}]]}], 
    ")"}]}]]], "Output",
 CellChangeTimes->{3.427147710531056*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"Gain", ",", "L"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gain", "[", 
     RowBox[{"C_", ",", "L_", ",", "\[Omega]_", ",", "R_"}], "]"}], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"abs", "[", "G", "]"}], "^", "2"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C", ",", "\[Omega]", ",", "L"}], "}"}], ">=", "0"}]}], " ", 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4271434320511827`*^9, 3.427143478274719*^9}, {
  3.427143596781917*^9, 3.427143647243469*^9}, {3.4271437761257668`*^9, 
  3.427143907458826*^9}, {3.42714395895678*^9, 3.4271440215790777`*^9}, {
  3.4271444405078363`*^9, 3.427144490003995*^9}, {3.427144561845787*^9, 
  3.427144562211996*^9}, {3.4271450179521723`*^9, 3.427145019191163*^9}, {
  3.427145163820736*^9, 3.427145164004023*^9}, {3.4271452422378473`*^9, 
  3.427145242590012*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["L", "2"], " ", 
   SuperscriptBox["\[Omega]", "2"]}], 
  RowBox[{
   RowBox[{
    SuperscriptBox["L", "2"], " ", 
    SuperscriptBox["\[Omega]", "2"]}], "+", 
   RowBox[{
    SuperscriptBox["R", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"C", " ", "L", " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], ")"}], "2"]}]}]]], "Output",
 CellChangeTimes->{3.427147714233246*^9, 3.427147777510331*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data", "Subsection",
 CellChangeTimes->{{3.427146119828341*^9, 3.42714612351457*^9}, {
  3.4271461542664557`*^9, 3.4271461573624573`*^9}}],

Cell["\<\
For better numerical stability I use frequency in kHz. Frequency = first \
column and |gain|^2 = second column. Since L and C enter as (f L) and (f C) \
in the gain formula, that means the actual values of L and C are smaller by a \
factor of 1000.  \
\>", "Text",
 CellChangeTimes->{{3.427142173392831*^9, 3.4271422081223097`*^9}, {
  3.427142720765334*^9, 3.4271427464261303`*^9}, {3.4271461361319523`*^9, 
  3.42714624570719*^9}, {3.4271474359487123`*^9, 3.427147494043091*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Data", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"0.0500", ",", "0.0001"}], "}"}], ",", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"0.1000", ",", "0.0004"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"0.5000", ",", " ", "0.0140"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.0000", ",", " ", "0.14065"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.2200", ",", " ", "0.4693"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.2300", ",", " ", "0.5169"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.2400", ",", " ", "0.5791"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.3000", ",", " ", "0.7953"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.3500", ",", " ", "0.8631"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.3800", ",", " ", "1.0388"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.4000", ",", " ", "1.0609"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.4100", ",", " ", "0.9977"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.4300", ",", " ", "1.0357"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.4500", ",", " ", "0.9188"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.4800", ",", " ", "0.8948"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.5000", ",", " ", "0.9017"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.6100", ",", " ", "0.5666"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.6200", " ", ",", "0.5549"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.6300", ",", " ", "0.5097"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"1.7000", " ", ",", "0.3468"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"2.0000", ",", " ", "0.1468"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"3.0000", ",", " ", "0.0309"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"4.0000", ",", " ", "0.0135"}], "}"}], ",", 
    RowBox[{"{", "\n", 
     RowBox[{"5.0000", ",", " ", "0.0079"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4271429821550913`*^9, 3.427142990051648*^9}, {
   3.427143039326798*^9, 3.427143051625978*^9}, {3.4271431117054453`*^9, 
   3.4271432422302523`*^9}, 3.4271433329998503`*^9, {3.427147500838934*^9, 
   3.427147505455702*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.05`", ",", "0.0001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.1`", ",", "0.0004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "0.014`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.14065`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.22`", ",", "0.4693`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.23`", ",", "0.5169`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.24`", ",", "0.5791`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3`", ",", "0.7953`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.35`", ",", "0.8631`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.38`", ",", "1.0388`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.4`", ",", "1.0609`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.41`", ",", "0.9977`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.43`", ",", "1.0357`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.45`", ",", "0.9188`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.48`", ",", "0.8948`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5`", ",", "0.9017`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.61`", ",", "0.5666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.62`", ",", "0.5549`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.63`", ",", "0.5097`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.7`", ",", "0.3468`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "0.1468`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.`", ",", "0.0309`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", "0.0135`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", "0.0079`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.427147719378187*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.427143249070127*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DPlot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"Data", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.05"}], ",", "1.1"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RGBColor", "[", 
        RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
       RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
    RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.427147370292904*^9, 3.427147371724208*^9}, {
  3.427147406558288*^9, 3.427147407236075*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[1, 0, 0], PointSize[0.02], 
    PointBox[{{0., 0.}, {0.05, 0.0001}, {0.1, 0.0004}, {0.5, 0.014}, {1., 
     0.14065}, {1.22, 0.4693}, {1.23, 0.5169}, {1.24, 0.5791}, {1.3, 
     0.7953}, {1.35, 0.8631}, {1.38, 1.0388}, {1.4, 1.0609}, {1.41, 0.9977}, {
     1.43, 1.0357}, {1.45, 0.9188}, {1.48, 0.8948}, {1.5, 0.9017}, {1.61, 
     0.5666}, {1.62, 0.5549}, {1.63, 0.5097}, {1.7, 0.3468}, {2., 0.1468}, {
     3., 0.0309}, {4., 0.0135}, {5., 0.0079}}]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction:>Identity,
  PlotRange->{{0., 5.}, {-0.05, 1.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.427147723639852*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "\"\<NonlinearRegression`\>\""}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"fit", "=", 
   RowBox[{"NonlinearRegress", "[", 
    RowBox[{"Data", ",", 
     RowBox[{"{", 
      RowBox[{"Gain", "[", 
       RowBox[{"C", ",", "L", ",", 
        RowBox[{"2", " ", "Pi", " ", "f"}], ",", "1050"}], "]"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"C", ",", 
         RowBox[{"330", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "9"}]]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"L", ",", ".0133"}], "}"}]}], "}"}], ",", "f"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.427144077622356*^9, 3.427144080635681*^9}, {
   3.427144124389482*^9, 3.427144144172967*^9}, 3.4271442024776707`*^9, {
   3.427144252781905*^9, 3.4271442559717417`*^9}, {3.427144383788474*^9, 
   3.4271443961817617`*^9}, 3.427144432616405*^9, {3.4271445226470413`*^9, 
   3.4271445422283707`*^9}, {3.427144644381998*^9, 3.427144653171708*^9}, {
   3.427145190941824*^9, 3.427145196772009*^9}, {3.427145378301427*^9, 
   3.427145379179915*^9}, {3.427145422270158*^9, 3.427145422652149*^9}, 
   3.42714585682866*^9, {3.427145916200427*^9, 3.427145916723962*^9}, {
   3.4271459545581217`*^9, 3.427145982220419*^9}, {3.4271460289341393`*^9, 
   3.4271460880598183`*^9}, {3.427147756298813*^9, 3.427147759836218*^9}, {
   3.42714780222234*^9, 3.4271478241720533`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"BestFitParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C", "\[Rule]", "0.00036498929109908947`"}], ",", 
      RowBox[{"L", "\[Rule]", "34.78834440807467`"}]}], "}"}]}], ",", 
   RowBox[{"ParameterCITable", "\[Rule]", 
    TagBox[
     TagBox[GridBox[{
        {
         StyleBox["\[Null]",
          ShowStringCharacters->False], 
         TagBox["\<\"Estimate\"\>",
          HoldForm], 
         TagBox["\<\"Asymptotic SE\"\>",
          HoldForm], 
         TagBox["\<\"CI\"\>",
          HoldForm]},
        {
         TagBox["C",
          HoldForm], "0.00036498929109908947`", "7.85278121591065`*^-6", 
         RowBox[{"{", 
          RowBox[{"0.00034874457547384014`", ",", "0.0003812340067243388`"}], 
          "}"}]},
        {
         TagBox["L",
          HoldForm], "34.78834440807467`", "0.7553136280028029`", 
         RowBox[{"{", 
          RowBox[{"33.22585912325345`", ",", "36.35082969289589`"}], "}"}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxDividers->{
        "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
         "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
     Function[BoxForm`e$, 
      TableForm[
      BoxForm`e$, TableDepth -> 2, 
       TableHeadings -> {{C, $CellContext`L}, {
         "Estimate", "Asymptotic SE", "CI"}}]]]}], ",", 
   RowBox[{"EstimatedVariance", "\[Rule]", "0.0009629962298225441`"}], ",", 
   RowBox[{"ANOVATable", "\[Rule]", 
    InterpretationBox[GridBox[{
       {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", "\<\"MeanSq\"\>"},
       {"\<\"Model\"\>", "2", "9.960439299214078`", "4.980219649607039`"},
       {"\<\"Error\"\>", "23", "0.022148913285918514`", 
        "0.0009629962298225441`"},
       {"\<\"Uncorrected Total\"\>", "25", "9.982588212499998`", "\<\"\"\>"},
       {"\<\"Corrected Total\"\>", "24", "3.8278722555999996`", "\<\"\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     TableForm[{{2, 9.960439299214078, 4.980219649607039}, {
       23, 0.022148913285918514`, 0.0009629962298225441}, {
       25, 9.982588212499998}, {24, 3.8278722555999996`}}, 
      TableHeadings -> {{
        "Model", "Error", "Uncorrected Total", "Corrected Total"}, {
        "DF", "SumOfSq", "MeanSq"}}]]}], ",", 
   RowBox[{"AsymptoticCorrelationMatrix", "\[Rule]", 
    TagBox[
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"0.9999999999999998`", 
         RowBox[{"-", "0.974242107485028`"}]},
        {
         RowBox[{"-", "0.9742421074850283`"}], "1.0000000000000004`"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
     Function[BoxForm`e$, 
      MatrixForm[BoxForm`e$]]]}], ",", 
   RowBox[{"FitCurvatureTable", "\[Rule]", 
    TagBox[
     TagBox[GridBox[{
        {
         StyleBox["\[Null]",
          ShowStringCharacters->False], 
         TagBox["\<\"Curvature\"\>",
          HoldForm]},
        {
         TagBox["\<\"Max Intrinsic\"\>",
          HoldForm], "0.05822524970149402`"},
        {
         TagBox["\<\"Max Parameter-Effects\"\>",
          HoldForm], "0.27027417357154243`"},
        {
         TagBox["\<\"95. % Confidence Region\"\>",
          HoldForm], "0.5405695869373592`"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxDividers->{
        "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
         "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
     Function[BoxForm`e$, 
      TableForm[
      BoxForm`e$, TableDepth -> 2, 
       TableHeadings -> {{
         "Max Intrinsic", "Max Parameter-Effects", 
          "95. % Confidence Region"}, {"Curvature"}}]]]}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.4271477326667843`*^9, 3.427147826305987*^9}}]
}, Open  ]],

Cell["\<\
Since L and C enter as (f L) and (f C) in the gain formula and we used f in \
kHz, that means the actual values are smaller by a factor of 1000.  \
\>", "Text",
 CellChangeTimes->{{3.427142173392831*^9, 3.4271422081223097`*^9}, {
  3.427142720765334*^9, 3.4271427464261303`*^9}, {3.4271461361319523`*^9, 
  3.427146296618582*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"value", "=", 
   RowBox[{"BestFitParameters", "/.", "fit"}]}], ";"}], "\[IndentingNewLine]",
 
 RowBox[{
  RowBox[{"Cft", "=", 
   RowBox[{
    RowBox[{"C", "/", "1000"}], "/.", "value"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Lft", " ", "=", 
  RowBox[{
   RowBox[{"L", "/", "1000"}], "/.", "value"}]}], "\[IndentingNewLine]", 
 RowBox[{"1", "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", "Pi", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"Lft", "*", "Cft"}], "]"}]}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.427144722139699*^9, 3.427144726702488*^9}, {
  3.427145515829191*^9, 3.427145579685101*^9}, {3.427146325283679*^9, 
  3.4271463275072737`*^9}, {3.4271465377729692`*^9, 3.427146547475449*^9}, {
  3.427146665845167*^9, 3.427146683596867*^9}, {3.427147220869011*^9, 
  3.427147231756019*^9}}],

Cell[BoxData["3.6498929109908947`*^-7"], "Output",
 CellChangeTimes->{3.4271478411051826`*^9}],

Cell[BoxData["0.03478834440807467`"], "Output",
 CellChangeTimes->{3.427147841129086*^9}],

Cell[BoxData["1412.4178256087519`"], "Output",
 CellChangeTimes->{3.4271478411655073`*^9}]
}, Open  ]],

Cell[" ", "Text",
 CellChangeTimes->{{3.427142173392831*^9, 3.4271422081223097`*^9}, {
  3.427142720765334*^9, 3.4271427464261303`*^9}, {3.4271461361319523`*^9, 
  3.427146296618582*^9}, {3.427147274475065*^9, 3.427147281738641*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TPlot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Gain", "[", 
     RowBox[{"Cft", ",", "Lft", ",", 
      RowBox[{"2", " ", "Pi", " ", "f", " ", "*", " ", "1000"}], ",", 
      "1050"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"f", ",", "0", ",", "5"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.05"}], ",", "1.1"}], "}"}]}], ",", 
    RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4271447013816423`*^9, 3.427144708467779*^9}, {
  3.427144910324162*^9, 3.427144929844132*^9}, {3.427145353974125*^9, 
  3.427145355411998*^9}, {3.427145475273939*^9, 3.427145486131897*^9}, {
  3.427145586102062*^9, 3.427145617006599*^9}, {3.427145658396071*^9, 
  3.42714566426746*^9}, {3.42714572706157*^9, 3.427145738843545*^9}, {
  3.427146370165802*^9, 3.427146431107727*^9}, {3.42714657190324*^9, 
  3.427146624405623*^9}, {3.427147261542721*^9, 3.427147264820201*^9}, {
  3.427147297229927*^9, 3.427147308404048*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc0198fB3C7QTIaUqEioaxvaSjPNxmRiChFEQmJqIiShEqys7L3yh4V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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction:>Identity,
  PlotRange->{{0, 5}, {-0.05, 1.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.427147845858368*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"TPlot", ",", "DPlot", ",", 
   RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<f [kHz]\>\"", ",", "\"\<Voltage gain\>\"", ",", 
      "\"\<Theory and Data\>\"", ",", "\"\<\>\""}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.4271422462927437`*^9, 3.427142251035631*^9}, {
  3.4271466459982433`*^9, 3.427146655110757*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc0198fB3C7QTIaUqEioaxvaSjPNxmRiChFEQmJqIiShEqys7L3yh4V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      "]]}}, {{}, 
    {RGBColor[1, 0, 0], PointSize[0.02], 
     PointBox[{{0., 0.}, {0.05, 0.0001}, {0.1, 0.0004}, {0.5, 0.014}, {1., 
      0.14065}, {1.22, 0.4693}, {1.23, 0.5169}, {1.24, 0.5791}, {1.3, 
      0.7953}, {1.35, 0.8631}, {1.38, 1.0388}, {1.4, 1.0609}, {1.41, 
      0.9977}, {1.43, 1.0357}, {1.45, 0.9188}, {1.48, 0.8948}, {1.5, 
      0.9017}, {1.61, 0.5666}, {1.62, 0.5549}, {1.63, 0.5097}, {1.7, 
      0.3468}, {2., 0.1468}, {3., 0.0309}, {4., 0.0135}, {5., 
      0.0079}}]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"f [kHz]\"", TraditionalForm], 
    FormBox["\"Voltage gain\"", TraditionalForm], 
    FormBox["\"Theory and Data\"", TraditionalForm], 
    FormBox["\"\"", TraditionalForm]},
  PlotRange->{{0, 5}, {-0.05, 1.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.427147849007607*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{955, 877},
WindowMargins->{{Automatic, 99}, {Automatic, 7}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (April 20, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 146, 4, 64, "Input"],
Cell[717, 27, 363, 6, 41, "Text"],
Cell[1083, 35, 209, 5, 27, "Input"],
Cell[CellGroupData[{
Cell[1317, 44, 552, 20, 51, "Subsection"],
Cell[1872, 66, 286, 5, 41, "Text"],
Cell[2161, 73, 323, 5, 89, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2521, 83, 38, 0, 67, "Section"],
Cell[2562, 85, 87, 2, 27, "Input"],
Cell[2652, 89, 593, 15, 27, "Input"],
Cell[CellGroupData[{
Cell[3270, 108, 102, 3, 27, "Input"],
Cell[3375, 113, 571, 18, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3983, 136, 979, 22, 58, "Input"],
Cell[4965, 160, 525, 17, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5527, 182, 144, 2, 34, "Subsection"],
Cell[5674, 186, 491, 8, 41, "Text"],
Cell[CellGroupData[{
Cell[6190, 198, 2389, 57, 388, "Input"],
Cell[8582, 257, 1794, 53, 73, "Output"]
}, Open  ]],
Cell[10391, 313, 68, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[10484, 318, 637, 16, 43, "Input"],
Cell[11124, 336, 801, 17, 237, "Output"]
}, Open  ]],
Cell[11940, 356, 72, 1, 27, "Input"],
Cell[CellGroupData[{
Cell[12037, 361, 1391, 30, 48, "Input"],
Cell[13431, 393, 5477, 136, 265, "Output"]
}, Open  ]],
Cell[18923, 532, 340, 6, 26, "Text"],
Cell[CellGroupData[{
Cell[19288, 542, 842, 22, 73, "Input"],
Cell[20133, 566, 94, 1, 30, "Output"],
Cell[20230, 569, 89, 1, 27, "Output"],
Cell[20322, 572, 90, 1, 27, "Output"]
}, Open  ]],
Cell[20427, 576, 233, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[20685, 583, 1061, 22, 27, "Input"],
Cell[21749, 607, 10161, 173, 237, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31947, 785, 525, 12, 43, "Input"],
Cell[32475, 799, 10877, 187, 256, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
